@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: parsers
 version: 0.12.3
-id: parsers-0.12.3-1e35467efed8fe38d8f3b579df5912e3
-key: parse_0An0lBhGE8V5O7tsoPIDxe
+id: parsers-0.12.3-e051a13a9521cc24fdedfec6256ef8b5
+key: parse_JO6CfgWE9SR45jHXewyF6O
 license: BSD3
 copyright: Copyright (C) 2010-2013 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -27,12 +27,12 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/parsers-0.12.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/parsers-0.12.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/parsers-0.12.3
-hs-libraries: HSparsers-0.12.3-0An0lBhGE8V5O7tsoPIDxe
+hs-libraries: HSparsers-0.12.3-JO6CfgWE9SR45jHXewyF6O
 depends:
-    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
+    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base-orphans-0.5.4-e40139ef3f9e9946a3f68f9fef66a420
-    charset-0.3.7.1-eb9c9b19f9448bfb51c91765226aa73d
+    charset-0.3.7.1-efbce7d7e6d5ad9047eb0bb349210702
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
     scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
